@@ -82,6 +82,7 @@ class MaoboApp(QApplication):
         self.logger = logging.getLogger('maebo')        
         self.logger.info("__initing__")
         
+        super(MaoboApp, self).__init__(parent)
     # Get the system bus
         sysbus=dbus.Bus.get_system()
 
@@ -93,7 +94,6 @@ class MaoboApp(QApplication):
         self.osso_rpc.set_rpc_callback(SH_DBUS_NAME, SH_DBUS_PATH, SH_DBUS_IFACE, self.send_via_service, self.osso_c)
 
         print str(time.time()) + ": " + "MaoboApp __init__ a" 
-        super(MaoboApp, self).__init__(parent)
         self.charm = FlickCharm()
 
         #print str(time.time()) + ": " + "MaoboApp __init__ b"   
@@ -128,6 +128,11 @@ class MaoboApp(QApplication):
 
         self.commentid_seed = 0
         self.create_accounts_window()
+        if len(self.accounts)==0:
+            self.create_default_window()
+            self.defaultWin.show()
+        else:
+            self.accountsWin.show()
 
         #print str(time.time()) + ": " + "MaoboApp __init__ 1"  
         
@@ -135,26 +140,38 @@ class MaoboApp(QApplication):
         self.senderqq_service=SenderQQ(self.show_notice)
 
         #self.clean_temp_images("/home/user/.sharing/outbox")
-        
-        Utils.g_orietation=self.get_current_orientation()
-        print Utils.g_orietation
+
 
         print str(time.time()) + ": " + "MaoboApp __init__ 2"
-        if len(self.accounts)==0:
-            self.create_default_window()
-            self.defaultWin.show()
-        else:
-            self.accountsWin.show()
-        
+                 
+        Utils.g_orietation=self.get_current_orientation()
+        print Utils.g_orietation
         self.create_timeline_window()
         self.create_status_window()
         self.newStatusWin=None
         self.accountsManaForm=None
         self.newAccountForm=None
-        self.defaultWin = None
+
+        self.init_unread_updaters()
+        
+        print "first threading start"
+        self.sm_auto_update_unread = _SM_AUTO_IDLE
+        self.t = threading.Timer(5.0, self.cb_update_unread_counts)
+        self.t.start()
+        print str(time.time()) + ": " + "MaoboApp __init__ 3"
+        
+        self.connect(self, SIGNAL("lastWindowClosed()"), self.lastWindowClosed)
+          
+    def lastWindowClosed(self):
+        print "lastWindowClosed"        
+        '''TODO: need to check the updaters state, and terminate them'''
+
+          
+    def init_unread_updaters(self):        
 
         self.unread_notifiers = {} #key = index of self.accounts
         self.unread_updaters = {} #key = accountid in database
+        
         i = 0
         for ac in self.accounts:
             #print ac["id"], ac["website"], ac["nickname"]
@@ -173,17 +190,6 @@ class MaoboApp(QApplication):
             self.unread_notifiers[str(i)+":t"+str(Utils.TIMELINE_TYPE_COMMENTS)] = 0
             i = i + 1
 
-        print "first threading start"
-        self.sm_auto_update_unread = _SM_AUTO_IDLE
-        self.t = threading.Timer(5.0, self.cb_update_unread_counts)
-        self.t.start()
-        print str(time.time()) + ": " + "MaoboApp __init__ 3"
-        
-        self.connect(self, SIGNAL("lastWindowClosed()"), self.lastWindowClosed)
-        
-    def lastWindowClosed(self):
-        print "lastWindowClosed"        
-        '''TODO: need to check the updaters state, and terminate them'''
 
 
     def change_current_timeline_view(self, account_idx, optype):
@@ -386,6 +392,9 @@ class MaoboApp(QApplication):
             #args[0] = account_idx, args[1] = optype
             print "open_mentions", args[0], args[1]
 
+            self.accountsWin.activateWindow()
+            self.accountsWin.show()
+            
             conn_status = self.osso_rpc.rpc_run("com.nokia.icd", "/com/nokia/icd", \
                 "com.nokia.icd", "get_state", wait_reply=True, use_system_bus=True)
             print "conn_status",conn_status
@@ -397,8 +406,6 @@ class MaoboApp(QApplication):
                 ret=self.osso_rpc.rpc_run("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd", "connect", \
                     rpc_args=(self.settings["auto_conn"], 0), wait_reply=True, use_system_bus=True)
             
-            self.accountsWin.activateWindow()
-            self.accountsWin.show()
 
             #print self.unread_notifiers[args[0]+":t"+args[1]].isVisible()
             self.unread_notifiers[args[0]+":t"+args[1]] = 0
@@ -1263,7 +1270,8 @@ class MaoboApp(QApplication):
             if self.defaultWin != None:
                 self.defaultWin.hide()
             self.accountsWin.show()
-            self.show_accounts_mana_form()
+            self.show_accounts_mana_form()       
+            self.init_unread_updaters()            
             self.accountsModel=AccountsModel(self.accounts,self.websites)
             self.accountsWin.accountsListView.setModel(self.accountsModel)
 
@@ -1377,7 +1385,8 @@ class MaeboService(dbus.service.Object):
     @dbus.service.method(dbus_interface=SESSION_DBUS_IFACE)
     def show_window(self):
         self.app.accountsWin.activateWindow()   
-        self.app.accountsWin.show()             
+        self.app.accountsWin.show()  
+        print "show_window"
 
 def main():    
     if dbus.SessionBus().request_name(SESSION_DBUS_NAME) != dbus.bus.REQUEST_NAME_REPLY_PRIMARY_OWNER:
@@ -1422,7 +1431,6 @@ def main():
 	    print str(time.time()) + ": " + "before app.exec_"
 
 	    service = MaeboService(app)
-	    
 
 	    app.exec_()
 	    print "after app.exec_"
